@@ -1,7 +1,7 @@
 '''
 # `provider`
 
-Refer to the Terraform Registory for docs: [`googleworkspace`](https://www.terraform.io/docs/providers/googleworkspace).
+Refer to the Terraform Registory for docs: [`googleworkspace`](https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs).
 '''
 import abc
 import builtins
@@ -26,7 +26,7 @@ class GoogleworkspaceProvider(
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-googleworkspace.provider.GoogleworkspaceProvider",
 ):
-    '''Represents a {@link https://www.terraform.io/docs/providers/googleworkspace googleworkspace}.'''
+    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs googleworkspace}.'''
 
     def __init__(
         self,
@@ -41,17 +41,17 @@ class GoogleworkspaceProvider(
         oauth_scopes: typing.Optional[typing.Sequence[builtins.str]] = None,
         service_account: typing.Optional[builtins.str] = None,
     ) -> None:
-        '''Create a new {@link https://www.terraform.io/docs/providers/googleworkspace googleworkspace} Resource.
+        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs googleworkspace} Resource.
 
         :param scope: The scope in which to define this construct.
         :param id: The scoped construct ID. Must be unique amongst siblings in the same scope
-        :param access_token: A temporary [OAuth 2.0 access token] obtained from the Google Authorization server, i.e. the ``Authorization: Bearer`` token used to authenticate HTTP requests to Google Admin SDK APIs. This is an alternative to ``credentials``, and ignores the ``oauth_scopes`` field. If both are specified, ``access_token`` will be used over the ``credentials`` field. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#access_token GoogleworkspaceProvider#access_token}
-        :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#alias GoogleworkspaceProvider#alias}
-        :param credentials: Either the path to or the contents of a service account key file in JSON format you can manage key files using the Cloud Console). If not provided, the application default credentials will be used. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#credentials GoogleworkspaceProvider#credentials}
-        :param customer_id: The customer id provided with your Google Workspace subscription. It is found in the admin console under Account Settings. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#customer_id GoogleworkspaceProvider#customer_id}
-        :param impersonated_user_email: The impersonated user's email with access to the Admin APIs can access the Admin SDK Directory API. ``impersonated_user_email`` is required for all services except group and user management. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#impersonated_user_email GoogleworkspaceProvider#impersonated_user_email}
-        :param oauth_scopes: The list of the scopes required for your application (for a list of possible scopes, see `Authorize requests <https://developers.google.com/admin-sdk/directory/v1/guides/authorizing>`_). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#oauth_scopes GoogleworkspaceProvider#oauth_scopes}
-        :param service_account: The service account used to create the provided ``access_token`` if authenticating using the ``access_token`` method and needing to impersonate a user. This service account will require the GCP role ``Service Account Token Creator`` if needing to impersonate a user. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#service_account GoogleworkspaceProvider#service_account}
+        :param access_token: A temporary [OAuth 2.0 access token] obtained from the Google Authorization server, i.e. the ``Authorization: Bearer`` token used to authenticate HTTP requests to Google Admin SDK APIs. This is an alternative to ``credentials``, and ignores the ``oauth_scopes`` field. If both are specified, ``access_token`` will be used over the ``credentials`` field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#access_token GoogleworkspaceProvider#access_token}
+        :param alias: Alias name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#alias GoogleworkspaceProvider#alias}
+        :param credentials: Either the path to or the contents of a service account key file in JSON format you can manage key files using the Cloud Console). If not provided, the application default credentials will be used. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#credentials GoogleworkspaceProvider#credentials}
+        :param customer_id: The customer id provided with your Google Workspace subscription. It is found in the admin console under Account Settings. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#customer_id GoogleworkspaceProvider#customer_id}
+        :param impersonated_user_email: The impersonated user's email with access to the Admin APIs can access the Admin SDK Directory API. ``impersonated_user_email`` is required for all services except group and user management. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#impersonated_user_email GoogleworkspaceProvider#impersonated_user_email}
+        :param oauth_scopes: The list of the scopes required for your application (for a list of possible scopes, see `Authorize requests <https://developers.google.com/admin-sdk/directory/v1/guides/authorizing>`_). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#oauth_scopes GoogleworkspaceProvider#oauth_scopes}
+        :param service_account: The service account used to create the provided ``access_token`` if authenticating using the ``access_token`` method and needing to impersonate a user. This service account will require the GCP role ``Service Account Token Creator`` if needing to impersonate a user. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#service_account GoogleworkspaceProvider#service_account}
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__ba5894dbbe4a2e3483e12acedce8a4b906b3a6a5d70aaec75b32c6df7b5c108f)
@@ -252,13 +252,13 @@ class GoogleworkspaceProviderConfig:
         service_account: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
-        :param access_token: A temporary [OAuth 2.0 access token] obtained from the Google Authorization server, i.e. the ``Authorization: Bearer`` token used to authenticate HTTP requests to Google Admin SDK APIs. This is an alternative to ``credentials``, and ignores the ``oauth_scopes`` field. If both are specified, ``access_token`` will be used over the ``credentials`` field. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#access_token GoogleworkspaceProvider#access_token}
-        :param alias: Alias name. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#alias GoogleworkspaceProvider#alias}
-        :param credentials: Either the path to or the contents of a service account key file in JSON format you can manage key files using the Cloud Console). If not provided, the application default credentials will be used. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#credentials GoogleworkspaceProvider#credentials}
-        :param customer_id: The customer id provided with your Google Workspace subscription. It is found in the admin console under Account Settings. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#customer_id GoogleworkspaceProvider#customer_id}
-        :param impersonated_user_email: The impersonated user's email with access to the Admin APIs can access the Admin SDK Directory API. ``impersonated_user_email`` is required for all services except group and user management. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#impersonated_user_email GoogleworkspaceProvider#impersonated_user_email}
-        :param oauth_scopes: The list of the scopes required for your application (for a list of possible scopes, see `Authorize requests <https://developers.google.com/admin-sdk/directory/v1/guides/authorizing>`_). Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#oauth_scopes GoogleworkspaceProvider#oauth_scopes}
-        :param service_account: The service account used to create the provided ``access_token`` if authenticating using the ``access_token`` method and needing to impersonate a user. This service account will require the GCP role ``Service Account Token Creator`` if needing to impersonate a user. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#service_account GoogleworkspaceProvider#service_account}
+        :param access_token: A temporary [OAuth 2.0 access token] obtained from the Google Authorization server, i.e. the ``Authorization: Bearer`` token used to authenticate HTTP requests to Google Admin SDK APIs. This is an alternative to ``credentials``, and ignores the ``oauth_scopes`` field. If both are specified, ``access_token`` will be used over the ``credentials`` field. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#access_token GoogleworkspaceProvider#access_token}
+        :param alias: Alias name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#alias GoogleworkspaceProvider#alias}
+        :param credentials: Either the path to or the contents of a service account key file in JSON format you can manage key files using the Cloud Console). If not provided, the application default credentials will be used. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#credentials GoogleworkspaceProvider#credentials}
+        :param customer_id: The customer id provided with your Google Workspace subscription. It is found in the admin console under Account Settings. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#customer_id GoogleworkspaceProvider#customer_id}
+        :param impersonated_user_email: The impersonated user's email with access to the Admin APIs can access the Admin SDK Directory API. ``impersonated_user_email`` is required for all services except group and user management. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#impersonated_user_email GoogleworkspaceProvider#impersonated_user_email}
+        :param oauth_scopes: The list of the scopes required for your application (for a list of possible scopes, see `Authorize requests <https://developers.google.com/admin-sdk/directory/v1/guides/authorizing>`_). Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#oauth_scopes GoogleworkspaceProvider#oauth_scopes}
+        :param service_account: The service account used to create the provided ``access_token`` if authenticating using the ``access_token`` method and needing to impersonate a user. This service account will require the GCP role ``Service Account Token Creator`` if needing to impersonate a user. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#service_account GoogleworkspaceProvider#service_account}
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__87b160856daefd564e852cb8095627bf815b9a8d8f80d11185d6d55195627b1d)
@@ -289,7 +289,7 @@ class GoogleworkspaceProviderConfig:
     def access_token(self) -> typing.Optional[builtins.str]:
         '''A temporary [OAuth 2.0 access token] obtained from the Google Authorization server, i.e. the ``Authorization: Bearer`` token used to authenticate HTTP requests to Google Admin SDK APIs. This is an alternative to ``credentials``, and ignores the ``oauth_scopes`` field. If both are specified, ``access_token`` will be used over the ``credentials`` field.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#access_token GoogleworkspaceProvider#access_token}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#access_token GoogleworkspaceProvider#access_token}
         '''
         result = self._values.get("access_token")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -298,7 +298,7 @@ class GoogleworkspaceProviderConfig:
     def alias(self) -> typing.Optional[builtins.str]:
         '''Alias name.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#alias GoogleworkspaceProvider#alias}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#alias GoogleworkspaceProvider#alias}
         '''
         result = self._values.get("alias")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -309,7 +309,7 @@ class GoogleworkspaceProviderConfig:
 
         If not provided, the application default credentials will be used.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#credentials GoogleworkspaceProvider#credentials}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#credentials GoogleworkspaceProvider#credentials}
         '''
         result = self._values.get("credentials")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -318,7 +318,7 @@ class GoogleworkspaceProviderConfig:
     def customer_id(self) -> typing.Optional[builtins.str]:
         '''The customer id provided with your Google Workspace subscription. It is found in the admin console under Account Settings.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#customer_id GoogleworkspaceProvider#customer_id}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#customer_id GoogleworkspaceProvider#customer_id}
         '''
         result = self._values.get("customer_id")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -329,7 +329,7 @@ class GoogleworkspaceProviderConfig:
 
         ``impersonated_user_email`` is required for all services except group and user management.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#impersonated_user_email GoogleworkspaceProvider#impersonated_user_email}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#impersonated_user_email GoogleworkspaceProvider#impersonated_user_email}
         '''
         result = self._values.get("impersonated_user_email")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -338,7 +338,7 @@ class GoogleworkspaceProviderConfig:
     def oauth_scopes(self) -> typing.Optional[typing.List[builtins.str]]:
         '''The list of the scopes required for your application (for a list of possible scopes, see `Authorize requests <https://developers.google.com/admin-sdk/directory/v1/guides/authorizing>`_).
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#oauth_scopes GoogleworkspaceProvider#oauth_scopes}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#oauth_scopes GoogleworkspaceProvider#oauth_scopes}
         '''
         result = self._values.get("oauth_scopes")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
@@ -349,7 +349,7 @@ class GoogleworkspaceProviderConfig:
 
         This service account will require the GCP role ``Service Account Token Creator`` if needing to impersonate a user.
 
-        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace#service_account GoogleworkspaceProvider#service_account}
+        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs#service_account GoogleworkspaceProvider#service_account}
         '''
         result = self._values.get("service_account")
         return typing.cast(typing.Optional[builtins.str], result)
